# x_image_picker

flutter 图片和视频选择器
* iOS基于[ZLPhotoBrowser](https://github.com/longitachi/ZLPhotoBrowser)
* Android基于[PictureSelector](https://github.com/LuckSiege/PictureSelector)
* 灵感来源于[images_picker](https://github.com/flutter-package/images_picker)
* 视频缩略图基于[video_thumbnail](https://github.com/justsoft/video_thumbnail)

## Android设置
1. 修改最低`SDK`版本为`19`, 文件路径`android/app/build.gradle`

```dtd
defaultConfig {
        applicationId "com.huanshao.x_image_picker_example"
        minSdkVersion 19 // here
        targetSdkVersion 30
        versionCode flutterVersionCode.toInteger()
        versionName flutterVersionName
    }
```

2. 添加依赖`androidx.camera:camera-camera2`

```dtd
dependencies {
    implementation "org.jetbrains.kotlin:kotlin-stdlib-jdk7:$kotlin_version"
    implementation "androidx.camera:camera-camera2:1.1.0-alpha06" // here
}
```

3. 修改`android/build.gradle`中`kotlin_version`的版本为`1.4.32`

```dtd
ext.kotlin_version = '1.4.32'
```

4. 添加`application`类, 并在`AndroidManifest.xml`的`application`标签中声明

```kotlin
package com.huanshao.x_image_picker_example

import android.app.Application
import androidx.camera.camera2.Camera2Config
import androidx.camera.core.CameraXConfig
import io.flutter.app.FlutterApplication

class MyApplication: FlutterApplication(), CameraXConfig.Provider {
    override fun onCreate() {
        super.onCreate()
    }


    override fun getCameraXConfig(): CameraXConfig {
        return Camera2Config.defaultConfig();
    }
}
```

```xml
<application
        android:label="x_image_picker_example"
        android:icon="@mipmap/ic_launcher"
       android:name=".MyApplication"
       >
.......
</application>
```

5. 添加权限

```xml
<uses-permission android:name="android.permission.READ_EXTERNAL_STORAGE" />
<uses-permission android:name="android.permission.WRITE_EXTERNAL_STORAGE" />
<uses-permission android:name="android.permission.CAMERA" />
<uses-permission android:name="android.permission.RECORD_AUDIO" />
```

## IOS设置

1. 添加权限描述
```xml
<key>NSCameraUsageDescription</key>
<string>使用相机</string>
<key>NSMicrophoneUsageDescription</key>
<string>使用麦克风</string>
<key>NSPhotoLibraryUsageDescription</key>
<string>访问相册</string>
```

2. IOS限制

    当前不支持从iCloud选择视频，当`XImagePickerArgsMediaType`为`Video`时且返回的`cover`为null时，请在
   flutter端做相应处理，比如告知用户此视频为iCloud存储，不支持选择，如果要选择此视频，可以到相册打开该视频，等
   视频下载完再选择该视频
   
## 使用
```dart
XImagePicker.pickImage(XImagePickerArgs(
                    type: XImagePickerArgsMediaType.Video,
                    recordVideoSecond: 10));
```

## 参数说明 `XImagePickerArgs`
```dart
final int recordVideoSecond;

  /// 最大选择数量
  final int maxSelectNum;

  /// 选择类型
  final XImagePickerArgsMediaType type;

  /// 是否显示拍照按钮
  final bool isCamera;

  XImagePickerArgs(
      {this.recordVideoSecond = 60,
      this.maxSelectNum = 9,
      required this.type,
      this.isCamera = true});
```

## 返回结果`XImagePickerResult`
```dart
final File file;
  final int width;
  final int height;

  /// 封面，仅当type 为[XImagePickerArgsMediaType.Video]有效
  File? cover;
```