package com.huanshao.x_image_picker

import android.app.Activity
import android.content.Context
import android.util.Log
import androidx.annotation.NonNull
import androidx.camera.core.CameraXConfig
import com.luck.picture.lib.PictureSelector
import com.luck.picture.lib.camera.CustomCameraView
import com.luck.picture.lib.config.PictureMimeType
import com.luck.picture.lib.entity.LocalMedia
import com.luck.picture.lib.listener.OnResultCallbackListener

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result

/** XImagePickerPlugin */
class XImagePickerPlugin: FlutterPlugin, MethodCallHandler, ActivityAware{
  private lateinit var channel : MethodChannel
  private lateinit var context: Context
  private lateinit var activity: Activity

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    context = flutterPluginBinding.applicationContext
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "x_image_picker")
    channel.setMethodCallHandler(this)
  }

  /*"isWithVideoImage": isWithVideoImage,
  "recordVideoSecond": recordVideoSecond,
  "maxSelectNum": maxSelectNum,
  "type": type.str,
  "isCamera": isCamera*/

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {
    if (call.method == "pick_image") {
      val recordVideoSecond = call.argument<Int>("recordVideoSecond") as Int
      val maxSelectNum = call.argument<Int>("maxSelectNum") as Int
      val isCamera = call.argument<Boolean>("isCamera") as Boolean
      val typeStr = call.argument<String>("type") as String

      var type: Int = PictureMimeType.ofAll()
      var buttonType: Int = CustomCameraView.BUTTON_STATE_BOTH

      when (typeStr){
        "Image" -> {
          type = PictureMimeType.ofImage()
          buttonType = CustomCameraView.BUTTON_STATE_ONLY_CAPTURE
        }
        "Video" -> {
          type = PictureMimeType.ofVideo()
          buttonType = CustomCameraView.BUTTON_STATE_ONLY_RECORDER
        }
      }

      PictureSelector.create(activity)
        .openGallery(type)
        .imageEngine(GlideEngine.createGlideEngine())
        .isUseCustomCamera(true)
        .videoMaxSecond(recordVideoSecond)
        .recordVideoSecond(recordVideoSecond)
        .isCamera(isCamera)
        .maxSelectNum(maxSelectNum)
        .maxVideoSelectNum(maxSelectNum)
        .setButtonFeatures(buttonType)
        .forResult(object : OnResultCallbackListener<LocalMedia>{
          override fun onCancel() {
          }

          override fun onResult(res: MutableList<LocalMedia>?) {
            var jsonStr = "["
            if(res != null && res.isNotEmpty()){
              for(item in res){
                jsonStr += "{\"path\":\"${item.realPath}\",\"width\":${item.width},\"height\":${item.height}},"
              }

              jsonStr = jsonStr.removeRange(jsonStr.length - 1, jsonStr.length)
              jsonStr+= "]"
              result.success(jsonStr)
            }
          }

        })
    } else {
      result.notImplemented()
    }
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    activity = binding.activity
  }

  override fun onDetachedFromActivityForConfigChanges() {
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
  }

  override fun onDetachedFromActivity() {
  }
}
