library x_image_picker;

import 'dart:convert';
import 'dart:io';

import 'package:flutter/services.dart';
import 'package:path_provider/path_provider.dart';
import 'package:video_thumbnail/video_thumbnail.dart';

part 'args.dart';

part 'result.dart';

class XImagePicker {
  static const MethodChannel _channel = const MethodChannel('x_image_picker');

  static Future<List<XImagePickerResult>?> pickImage(
      XImagePickerArgs args) async {
    final res = await _channel.invokeMethod("pick_image", args.toMap());

    if (res != null) {
      final list = res is List ? res : json.decode(res);
      final realList = (() sync* {
        for (var item in list) {
          final _item = {
            "path": item["path"],
            "width": item["width"],
            "height": item["height"]
          };

          final realItem = XImagePickerResult.fromMap(_item);

          if ((item as Map).containsKey("coverPath")) {
            realItem._coverPath = item["coverPath"];
          }
          yield realItem;
        }
      }())
          .toList();

      if (args.type == XImagePickerArgsMediaType.Video) {
        final tmpPath = await getTemporaryDirectory();
        for (int i = 0; i < realList.length; i++) {
          if (realList[i]._coverPath != null) {
            realList[i].cover = File(realList[i]._coverPath!);
          } else {
            try {
              final thumb = await VideoThumbnail.thumbnailFile(
                  video: realList[i].file.path, thumbnailPath: tmpPath.path);

              if (thumb != null) {
                realList[i].cover = File(thumb);
              }
            } catch (e) {
              print("视频缩略图生成失败");
            }
          }
        }
      }

      return realList;
    }
  }
}
